.. tlsmate documentation master file

Welcome to tlsmate's documentation!
===================================

This project provides a TLS server scanner written in Python. It supports
creating arbitrary TLS scenarios in a comfortable way as well.

The project is hosted on `GitLab <https://gitlab.com/guballa/tlsmate>`_.

.. toctree::
   :caption: General
   :maxdepth: 3

   overview
   installation
   usage
   scanner_output
   tlsfeatures

.. toctree::
   :caption: Command Line Interface
   :maxdepth: 2

   cli_config
   cli

.. toctree::
   :caption: Extending tlsmate
   :maxdepth: 2

   plain_python
   plugin
   class_description
   testcase
   style

.. toctree::
   :caption: Python Modules
   :maxdepth: 2

   modules
   mod_plugins
   mod_workers


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
